import sys
import dbus

class Hook:
  def __init__(self, action, service):
    self.action = action
    self.service = service

  def _action(self):
    if self.action == 'bitnami_restart':
      # bitnami hook (https://docs.bitnami.com/aws/infrastructure/rabbitmq/administration/control-services/)
      import subprocess
      subprocess.run(['sudo', '/opt/bitnami/ctlscript.sh', 'restart', self.service])
    else:
      # systemd hook
      bus = dbus.SystemBus()
      systemd = bus.get_object('org.freedesktop.systemd1', '/org/freedesktop/systemd1')
      manager = dbus.Interface(systemd, 'org.freedesktop.systemd1.Manager')

      if self.action == 'reload':
        managerMethod = manager.ReloadUnit
      elif self.action == 'restart':
        managerMethod = manager.RestartUnit
      else:
        sys.exit('Action must be "reload" or "restart"')

      managerMethod(self.service + '.service', 'replace')

  def run(self):
    self._action()



import argparse
from os import path
from pathlib import Path

parser = argparse.ArgumentParser(
  description='Deploy Azure Key Vault Certificates'
)

parser.add_argument(
  '-c', '--config-file',
  nargs='?',
  type=argparse.FileType('r'),
  default=path.join(
    Path.home(),
    '.keyvault-cert-downloader/config.yaml'
  )
)

args = parser.parse_args()



import yaml
from .args import args

config = yaml.load(args.config_file, Loader=yaml.FullLoader)

if len(config['keyvaults'].keys()) > 1:
    raise RuntimeError('Only one Key Vault supported in MVP')



from azure.identity import DefaultAzureCredential
from azure.keyvault.secrets import SecretClient

class Keyvault:
  def __init__(self, name):
    self._uri = 'https://{}.vault.azure.net'.format(name)
    self.__kv_client = None

  @property
  def _kv_client(self):
    if self.__kv_client is None:
      self.__kv_client = SecretClient(
        vault_url=self._uri,
        credential=DefaultAzureCredential()
      )
    return self.__kv_client

  @property
  def _secret_list(self):
    return self._kv_client.list_properties_of_secrets()
  
  def _get_secret(self, name):
    secret = self._kv_client.get_secret
    return secret(name)

  @property
  def secrets(self):
    return map(lambda s: self._get_secret(s.name), self._secret_list)
